pub struct Event {
pub propagate: bool,
pub future: Option<Pin<Box<dyn Future<Output = Box<dyn Any + Send + Sync>> + Send>>>,
pub prevent_defaults: bool,
pub target: Option<String>,
pub current_target: Option<String>,
pub window: WindowContext,
/* private fields */
}Expand description
The result of an update.
Fields
propagate: boolPropagate craft_events to the next element. True by default.
future: Option<Pin<Box<dyn Future<Output = Box<dyn Any + Send + Sync>> + Send>>>A future that will produce a message when complete. The message will be sent to the origin component.
prevent_defaults: boolPrevent default event handlers from running when an craft_event is not explicitly handled. False by default.
target: Option<String>current_target: Option<String>window: WindowContextImplementations
Sourceimpl Event
impl Event
pub fn with_window_context(window: WindowContext) -> Event
pub fn async_result<T>(t: T) -> Box<dyn Any + Send + Sync>
pub fn async_no_result() -> Box<dyn Any + Send>
Sourceimpl Event
impl Event
pub fn new() -> Event
pub fn pinned_future( &mut self, future: Pin<Box<dyn Future<Output = Box<dyn Any + Send + Sync>> + Send>>, )
pub fn future<F>(&mut self, future: F)
pub fn prevent_defaults(&mut self)
pub fn prevent_propagate(&mut self)
pub fn pointer_capture(&mut self, pointer_capture: PointerCapture)
pub fn add_effect( &mut self, event_dispatch_type: EventDispatchType, message: Message, )